# Generated by Django 2.2.9 on 2020-01-17 15:39

import uuid

import django.contrib.postgres.fields.hstore
import django.db.models.deletion
import enumfields.fields
from django.db import migrations, models
from enumfields import Enum

import arkindex.documents.dates
import arkindex.documents.models
import arkindex.project.fields
import arkindex_common.enums


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('images', '0001_initial'),
        ('dataimport', '0001_initial'),
    ]

    operations = [
        # Leave this when resetting migrations to avoid issues with HStoreField
        # django.db.utils.ProgrammingError: type "hstore" does not exist
        migrations.RunSQL(
            "CREATE EXTENSION IF NOT EXISTS hstore",
            reverse_sql=migrations.RunSQL.noop,
        ),
        migrations.CreateModel(
            name='AllowedMetaData',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('type', enumfields.fields.EnumField(enum=arkindex_common.enums.MetaType, max_length=50)),
                ('name', models.CharField(max_length=250)),
            ],
            options={
                'ordering': ('corpus', 'type', 'name'),
            },
        ),
        migrations.CreateModel(
            name='Classification',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('high_confidence', models.BooleanField(default=False)),
                ('state', enumfields.fields.EnumField(db_index=True, default='pending', enum=arkindex.documents.models.ClassificationState, max_length=16)),
                ('confidence', models.FloatField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='Corpus',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=250)),
                ('description', models.TextField(default='')),
                ('public', models.BooleanField(default=False)),
            ],
            options={
                'verbose_name_plural': 'corpora',
            },
        ),
        migrations.CreateModel(
            name='DataSource',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('type', enumfields.fields.EnumField(enum=Enum('MLToolType', ''), max_length=10)),
                ('slug', models.CharField(max_length=100)),
                ('name', models.CharField(max_length=100)),
                ('revision', models.CharField(max_length=100)),
                ('internal', models.BooleanField()),
            ],
        ),
        migrations.CreateModel(
            name='Element',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('updated', models.DateTimeField(auto_now=True)),
                ('name', models.CharField(max_length=250)),
            ],
            options={
                'abstract': False,
            },
        ),
        migrations.CreateModel(
            name='ElementPath',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('path', arkindex.project.fields.ArrayField(base_field=models.UUIDField(), size=None)),
                ('ordering', models.PositiveIntegerField(default=0)),
            ],
        ),
        migrations.CreateModel(
            name='ElementType',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('slug', models.SlugField()),
                ('display_name', models.CharField(max_length=250)),
                ('folder', models.BooleanField(default=False)),
                ('hidden', models.BooleanField(default=False)),
                ('default_view', models.BooleanField(default=False)),
            ],
        ),
        migrations.CreateModel(
            name='Entity',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.TextField()),
                ('type', enumfields.fields.EnumField(db_index=True, enum=arkindex_common.enums.EntityType, max_length=50)),
                ('metas', django.contrib.postgres.fields.hstore.HStoreField(blank=True, null=True)),
                ('validated', models.BooleanField(default=False)),
                ('corpus', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='entities', to='documents.Corpus')),
            ],
            options={
                'verbose_name_plural': 'Entities',
            },
            bases=(arkindex.documents.dates.InterpretedDateMixin, models.Model),
        ),
        migrations.CreateModel(
            name='MLClass',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=100)),
                ('corpus', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='ml_classes', to='documents.Corpus')),
            ],
            options={
                'verbose_name_plural': 'classes',
                'ordering': ('corpus', 'name'),
            },
        ),
        migrations.CreateModel(
            name='Region',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('confidence', models.FloatField(blank=True, null=True)),
            ],
            options={
                'default_related_name': 'regions',
            },
        ),
        migrations.CreateModel(
            name='Transcription',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('type', models.CharField(db_index=True, default='word', max_length=50)),
                ('text', models.TextField(blank=True, null=True)),
                ('score', models.FloatField(blank=True, null=True)),
                ('element', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcriptions', to='documents.Element')),
            ],
        ),
        migrations.CreateModel(
            name='TranscriptionEntity',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('offset', models.PositiveIntegerField()),
                ('length', models.PositiveIntegerField()),
                ('entity', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcription_entities', to='documents.Entity')),
                ('transcription', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcription_entities', to='documents.Transcription')),
            ],
        ),
        migrations.AddField(
            model_name='transcription',
            name='entities',
            field=models.ManyToManyField(related_name='transcriptions', through='documents.TranscriptionEntity', to='documents.Entity'),
        ),
        migrations.AddField(
            model_name='transcription',
            name='source',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='transcriptions', to='documents.DataSource'),
        ),
        migrations.AddField(
            model_name='transcription',
            name='zone',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='transcriptions', to='images.Zone'),
        ),
        migrations.CreateModel(
            name='RegionElement',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('ordering', models.PositiveIntegerField(default=0)),
                ('element', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='region_elements', to='documents.Element')),
                ('region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='region_elements', to='documents.Region')),
            ],
            options={
                'ordering': ('element', 'ordering'),
                'default_related_name': 'region_elements',
            },
        ),
        migrations.AddField(
            model_name='region',
            name='elements',
            field=models.ManyToManyField(related_name='regions', through='documents.RegionElement', to='documents.Element'),
        ),
        migrations.AddField(
            model_name='region',
            name='ml_class',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='regions', to='documents.MLClass'),
        ),
        migrations.AddField(
            model_name='region',
            name='source',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='regions', to='documents.DataSource'),
        ),
        migrations.AddField(
            model_name='region',
            name='zone',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='regions', to='images.Zone'),
        ),
        migrations.CreateModel(
            name='MetaData',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('name', models.CharField(max_length=250)),
                ('type', enumfields.fields.EnumField(db_index=True, enum=arkindex_common.enums.MetaType, max_length=50)),
                ('value', models.TextField()),
                ('index', models.PositiveIntegerField(default=0)),
                ('element', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='metadatas', to='documents.Element')),
                ('entity', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='metadatas', to='documents.Entity')),
                ('revision', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='dataimport.Revision')),
            ],
            options={
                'ordering': ('element', 'name', 'index'),
            },
            bases=(arkindex.documents.dates.InterpretedDateMixin, models.Model),
        ),
        migrations.CreateModel(
            name='EntityRole',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('parent_name', models.CharField(max_length=250)),
                ('child_name', models.CharField(max_length=250)),
                ('parent_type', enumfields.fields.EnumField(enum=arkindex_common.enums.EntityType, max_length=50)),
                ('child_type', enumfields.fields.EnumField(enum=arkindex_common.enums.EntityType, max_length=50)),
                ('corpus', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='roles', to='documents.Corpus')),
            ],
        ),
        migrations.CreateModel(
            name='EntityLink',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
                ('child', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='children', to='documents.Entity')),
                ('parent', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='parents', to='documents.Entity')),
                ('role', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='links', to='documents.EntityRole')),
            ],
        ),
    ]
